import * as React from "react";
import {FormEvent} from "react";
import {Button, Card, Form, message} from "antd";
import {observer} from "mobx-react";
import {NewEntity_1Management} from "./NewEntity_1Management";
import {FormComponentProps} from "antd/lib/form";
import {Link, Redirect} from "react-router-dom";
import {IReactionDisposer, observable, reaction} from "mobx";
import {collection, FormField, instance, Msg} from "@cuba-platform/react";
import {NewEntity_1} from "../../cuba/entities/testreactui_NewEntity_1";
import {NewEntity} from "../../cuba/entities/testreactui_NewEntity";


type Props = FormComponentProps & {
  entityId: string;
};


@observer
class NewEntity_1Edit extends React.Component<Props> {

  dataInstance = instance<NewEntity_1>(NewEntity_1.NAME, {view: 'newEntity_1-view', loadImmediately: false});
  linksDc = collection<NewEntity>(NewEntity.NAME, {view: '_minimal'});
  
  @observable
  updated = false;
  reactionDisposer: IReactionDisposer;

  fields = ['nameField','date','link',];

  handleSubmit = (e: FormEvent) => {
    e.preventDefault();
    this.props.form.validateFields((err, values) => {
      if (err) {
        message.warn('Validation Error. Please check the data you entered.');
        return;
      }
      this.dataInstance.update(this.props.form.getFieldsValue(this.fields))
        .then(() => {
          message.success('Entity has been updated');
          this.updated = true;
        })
        .catch(() => {
          alert('Error')
        });
    });
  };

  render() {

    if (this.updated) {
      return <Redirect to={NewEntity_1Management.PATH}/>
    }

    const {getFieldDecorator} = this.props.form;
    const {status} = this.dataInstance;

    return (
      <Card className='page-layout-narrow'>
        <Form onSubmit={this.handleSubmit}
              layout='vertical'>
          
          <Form.Item label={<Msg entityName={NewEntity_1.NAME} propertyName='nameField'/>}
                    key='nameField'
                    style={{marginBottom: '12px'}}>{
              getFieldDecorator('nameField', {})(
                <FormField entityName={NewEntity_1.NAME}
                          propertyName='nameField'/>
              )}
          </Form.Item>
          
          <Form.Item label={<Msg entityName={NewEntity_1.NAME} propertyName='date'/>}
                    key='date'
                    style={{marginBottom: '12px'}}>{
              getFieldDecorator('date', {})(
                <FormField entityName={NewEntity_1.NAME}
                          propertyName='date'/>
              )}
          </Form.Item>
          
          <Form.Item label={<Msg entityName={NewEntity_1.NAME} propertyName='link'/>}
                    key='link'
                    style={{marginBottom: '12px'}}>{
              getFieldDecorator('link', {})(
                <FormField entityName={NewEntity_1.NAME}
                          propertyName='link'
                          optionsContainer={this.linksDc}
                          />
              )}
          </Form.Item>
          
          <Form.Item style={{textAlign: 'center'}}>
            <Link to={NewEntity_1Management.PATH}>
              <Button htmlType="button">
                Cancel
              </Button>
            </Link>
            <Button type="primary"
                    htmlType="submit"
                    disabled={status !== "DONE" && status !== "ERROR"}
                    loading={status === "LOADING"}
                    style={{marginLeft: '8px'}}>
              Submit
            </Button>
          </Form.Item>
        </Form>
      </Card>
    );
  }

  componentDidMount() {
    if (this.props.entityId !== NewEntity_1Management.NEW_SUBPATH) {
      this.dataInstance.load(this.props.entityId);
    } else {
      this.dataInstance.setItem(new NewEntity_1());
    }
    this.reactionDisposer = reaction(
      () => {
        return this.dataInstance.item
      },
      () => {
        this.props.form.setFieldsValue(this.dataInstance.getFieldValues(this.fields));
      }
    )
  }

  componentWillUnmount() {
    this.reactionDisposer();
  }

}

export default Form.create<Props>()(NewEntity_1Edit);
